@@ -452,7 +452,7 @@ c calculate the fractional mass lost
 c
 
         frac_m = r_shear / sheath
-        masszt1 = masszt1 * (1.0 - fract_m)
+        masszt1 = masszt1 * (1.0 - frac_m)
 c
 c      Radial
 c
