@@ -13,6 +13,7 @@ c                 function to eliminate compiler warnings
 c 2015-06-23 RBS: Indexout initialized, zdemfmt.h removed as not needed
 c 2017-02-24 RBS: Changed the lblout definition from using currline to
 c                 using currline_lc
+c 2018-02-22 RBS: Added a new output parameter closs in Zflow/MITL
 c---------------------------------------------------------------------
 
       subroutine readscreameroutputs(status)
@@ -613,13 +614,18 @@ c
           labelidr = 'XMF'
           indextyp = ip_xmfi
 c
-c --- KWS Zflow Plasma Loss Model ---
+c --- KWS Zflow Plasma Loss Model MITL Model ---
 c
         else if (keyword .eq. k_aloss) then
           labelout = 'Anode Loss Current Density'
           labelplt = 'aloss'
           labelidr = 'ALO'
           indextyp = ip_aloss
+        else if (keyword .eq. k_closs) then
+          labelout = 'Anode Loss Current'
+          labelplt = 'closs'
+          labelidr = 'CLO'
+          indextyp = ip_closs
 c
 c --- KWS Measure Zflow and Cathode Current Block ---
 c
@@ -721,8 +727,11 @@ c
 c
 c First, test to see if a time_flag value has been entered. Then
 c test to see if Tstart and Tstop have been entered, if not, then set
-c them to 0 and end time, respectively.
+c them to 0 and end time, respectively. Here we have the option that if
+c no time_flag has been entered tstart an tstop can still be entered
 c
+c First field is output type, second field is output para,eter
+c Third field is the (time_flag_ option
         jj = 3
         call strip (field(jj), istart, iend)
         if (istart .ne. notext) then
@@ -730,6 +739,8 @@ c
           if (flag .eq. err) then
              flag = noerr
              keyword = field(jj)(1:keyword_len)
+c could check for a third keyword - scale
+c else if keyword .eq. k_scale) then
              if (keyword .eq. k_wholestep) then
                 time_flag = whole_step
              else
@@ -737,6 +748,7 @@ c
              endif
              jj = jj + 1
              call strip (field(jj), istart, iend)
+c enter scale factor here when keyword is scale
              if (istart .ne. notext) then
                 call text_to_real (field(jj), tstart, flag)
                 jj = jj + 1
