@@ -20,7 +20,8 @@ c                 function to eliminate compiler warnings
 c 2015-06-23 RBS: Definition of nsteps now explicitly integer
 c 2015-06-23 RBS: nvar_node initialized
 c 2015-09-25 RBS: Buffer*80 size exceeded in node max check write. That
-c                 write replaced with a dirct screen write.
+c                 write replaced with a direct screen write.
+c 2018-07-20 RBS: Initialized itabnum
 c
 c ----------------------------------------------------------------------
 c
@@ -65,7 +66,7 @@ c if everything is fine, we will return 0 in status
       character  initln*80
 c
 c----Variable definition for C++ stdout-----------------------------
-      character buffer*80
+c      character buffer*80
 c-------------------------------------------------------------------
 c
       initln  = 'Initial SCREAMER Circuit Status'
@@ -190,6 +191,7 @@ c
       ics_counter   = 0
       ic_counter    = 0
       itab_counter  = 0
+      itabnum       = 0
       icout         = 0
 c
 c Loop over the branches and set the number of blocks in that branch.
@@ -499,4 +501,4 @@ c
       end do
 
 802   return
-      end
\ No newline at end of file
+      end
