@@ -12,10 +12,12 @@ c    2014-11-15 RBS: Changed the version to 4.0
 c    2015-12-28 RBS: Changed the version to 4.1.4.1
 c    2015-12-28 RBS: Changed the version to 4.2
 c    2017-02-08 RBS: Changed the version to 4.2.3
+c    2017-09-19 RBS: Changed the version to 4.2.6
+c    2018-06-13 RBS: Changed the version to 4.2.7
 c
 c Character strings for SCREAMER version.
 c Edit this string as version changes
 c
       character*(*) screamer_version
       parameter (screamer_version =
-     & 'SCREAMER v4.2.4')
+     & 'SCREAMER v4.2.7.1')
